SOURCES.txt

MANIFEST.in Makefile README.html README.rst build_dist.sh conf.py genindex.html index.html index.rst portio.c portio.c.in pyproject.toml search.html setup.py toggle.py _sources/README.rst.html _sources/README.rst.txt _sources/index.rst.html _sources/index.rst.txt _sources/toggle.py _static/alabaster.css _static/basic.css _static/custom.css _static/doctools.js _static/documentation_options.js _static/file.png _static/forkme_right_darkblue_121621.png _static/language_data.js _static/minus.png _static/plus.png _static/pygments.css _static/searchtools.js _static/sphinx_highlight.js portio.egg-info/PKG-INFO portio.egg-info/SOURCES.html portio.egg-info/SOURCES.txt portio.egg-info/dependency_links.html portio.egg-info/dependency_links.txt portio.egg-info/top_level.html portio.egg-info/top_level.txt